@@ -1,37 +1,51 @@
-/* @(#) $Header: gnuc.h,v 1.1 95/03/04 02:59:35 leres Exp $ (LBL) */
+/* @(#) $Id: gnuc.h,v 1.5 2008/02/07 05:31:30 root Exp $ (LBL) */
 
 /* Define __P() macro, if necessary */
 #ifndef __P
-#ifndef __GNUC__
-#define __P(protos) ()
-#else
+#if __STDC__
 #define __P(protos) protos
+#else
+#define __P(protos) ()
 #endif
 #endif
 
 /* inline foo */
+#ifndef inline
 #ifdef __GNUC__
 #define inline __inline
 #else
 #define inline
 #endif
+#endif
 
 /*
  * Handle new and old "dead" routine prototypes
  *
  * For example:
  *
- *	__dead void foo(void) __attribute__((volatile));
+ *	__dead void foo(void) __attribute__((noreturn));
  *
  */
 #ifdef __GNUC__
 #ifndef __dead
+#if __GNUC__ >= 4
+#define __dead
+#define noreturn __noreturn__
+#else
 #define __dead volatile
+#define noreturn volatile
+#endif
 #endif
 #if __GNUC__ < 2  || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
+#ifndef __attribute__
 #define __attribute__(args)
 #endif
+#endif
 #else
-#define __attribute__(args)
+#ifndef __dead
 #define __dead
 #endif
+#ifndef __attribute__
+#define __attribute__(args)
+#endif
+#endif
